@@ -1,4 +1,4 @@
-from .sleep import SleepFeeder, SleepDownloader
+from .sleep import SleepFeeder, SleepDownloader, SleepFliter, SleepAmplifier
 from .random import RandomFeeder, RandomFilterFeeder, RandomFilterDownloader
 from .just import JustDownloader, JustLogCallbackDownloader
 from .subprocess import SubprocessDownloader
